#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-H7IxbbuirgGBxHz0nmGir5
key:                  wai-websockets-3.0.1.2-H7IxbbuirgGBxHz0nmGir5
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  78a62c3301147a68669edec62c48b8be
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-H7IxbbuirgGBxHz0nmGir5
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9SCmNmyRT1LDc1Bi3mXj6e
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o transformers-0.6.1.0
    wai-3.2.5-H9aJt8uWBWE1hbliPLgYgy
    websockets-0.12.7.3-2hMJvfWkUFQCaJOo4HIB6X

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

